==> mx-boot-options_19.5.1.tar.xz: mx-boot-options-19.5.1/translations/mx-boot-options_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Livemiljø registreret. Vælg venligst rodpartitionen på
 det system du vil ændre (der vises kun Linux-partitioner)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Kernel parameters</source>
        <translation>Kerneparametre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Indstil til &apos;0&apos; for at opstarte med det samme uden at vise menuen, eller til &apos;-1&apos; for at vente uendeligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Menu timeout</source>
        <translation>Timeout for menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Boot to</source>
        <translation>Opstart til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Brug forenklet menustruktur uden undermenuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Brug flade menuer (ingen undermenuer)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Når valgmuligheden er aktiveret, så gemmes det du vælger fra grub-opstartsmenuen som den nye standard til fremtidige opstarter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>Enable saving last boot choice</source>
        <translation>Aktivér husk sidst valgte opstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Background</source>
        <translation>Baggrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Image</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Enable theme</source>
        <translation>Aktivér tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Splash</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Messages</source>
        <translation>Meddelelser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Very detailed</source>
        <translation>Meget detaljeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljeret (standardindstilling)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Limited</source>
        <translation>Begrænset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Display log</source>
        <translation>Vis log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Still running</source>
        <translation>Kører stadig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installer opstartsbillede, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Updating sources</source>
        <translation>Opdaterer kilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>Installing</source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Could not install the bootsplash.</source>
        <translation>Kunne ikke installere opstartsbilledet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot continue</source>
        <translation>Kan ikke fortsætte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Intet blev valgt, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Kan ikke oprette chroot-miljø, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Updating configuration, please wait</source>
        <translation>Opdaterer konfiguration, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Updating initramfs...</source>
        <translation>Opdaterer initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="898"/>
        <source>Updating grub...</source>
        <translation>Opdaterer grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Changes have been successfully applied.</source>
        <translation>Ændringerne er blevet anvendt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="651"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <source>Changelog</source>
        <translation>Ændringlog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>MX Boot Options</source>
        <translation>MX Opstartsvalgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kører i en virtuel maskine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Dit nuværende system kører i en virtuel maskine,
Plymouth-opstartsbillede virker på en begrænset måde og du vil heller ikke være i stand til at forhåndsvise temaet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-pakker ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-pakker er ikke installeret.
Er det OK at fortsætte og installere dem?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Billeder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Press any key to close</source>
        <translation>Tryk på en tast for at lukke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Log not found</source>
        <translation>Log ikke fundet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Could not find log at </source>
        <translation>Kunne ikke finde log i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Needs reboot</source>
        <translation>Behøver genstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth blev lige installeret, det kan være nødvendigt at genstarte inden du kan vise forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>Click to select theme</source>
        <translation>Klik for at vælge tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as root.</source>
        <translation>Du skal køre programmet som root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="739"/>
        <source>Select image to display in bootloader</source>
        <translation>Vælg billede som skal vises i opstartsindlæser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="929"/>
        <source>Select GRUB theme</source>
        <translation>Vælg GRUB-tema</translation>
    </message>
</context>
</TS>

==> mx-boot-options_21.1.01.tar.xz: mx-boot-options-21.1.01/translations/mx-boot-options_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Livemiljø registreret. Vælg venligst rodpartitionen på
 det system du vil ændre (der vises kun Linux-partitioner)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="38"/>
        <source>Kernel parameters</source>
        <translation>Kerneparametre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Indstil til &apos;0&apos; for at opstarte med det samme uden at vise menuen, eller til &apos;-1&apos; for at vente uendeligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Menu timeout</source>
        <translation>Timeout for menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Boot to</source>
        <translation>Opstart til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Brug forenklet menustruktur uden undermenuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Brug flade menuer (ingen undermenuer)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Når valgmuligheden er aktiveret, så gemmes det du vælger fra grub-opstartsmenuen som den nye standard til fremtidige opstarter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>Enable saving last boot choice</source>
        <translation>Aktivér husk sidst valgte opstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Background</source>
        <translation>Baggrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Image</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Enable theme</source>
        <translation>Aktivér tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Splash</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Messages</source>
        <translation>Meddelelser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Very detailed</source>
        <translation>Meget detaljeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljeret (standardindstilling)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Limited</source>
        <translation>Begrænset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Display log</source>
        <translation>Vis log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Still running</source>
        <translation>Kører stadig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installer opstartsbillede, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Updating sources</source>
        <translation>Opdaterer kilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Installing</source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Could not install the bootsplash.</source>
        <translation>Kunne ikke installere opstartsbilledet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot continue</source>
        <translation>Kan ikke fortsætte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Intet blev valgt, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Kan ikke oprette chroot-miljø, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>Updating configuration, please wait</source>
        <translation>Opdaterer konfiguration, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>Updating initramfs...</source>
        <translation>Opdaterer initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>Updating grub...</source>
        <translation>Opdaterer grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Changes have been successfully applied.</source>
        <translation>Ændringerne er blevet anvendt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>Changelog</source>
        <translation>Ændringlog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>MX Boot Options</source>
        <translation>MX Opstartsvalgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="723"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kører i en virtuel maskine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Dit nuværende system kører i en virtuel maskine,
Plymouth-opstartsbillede virker på en begrænset måde og du vil heller ikke være i stand til at forhåndsvise temaet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-pakker ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-pakker er ikke installeret.
Er det OK at fortsætte og installere dem?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="750"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Billeder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Press any key to close</source>
        <translation>Tryk på en tast for at lukke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Log not found</source>
        <translation>Log ikke fundet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Could not find log at </source>
        <translation>Kunne ikke finde log i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Needs reboot</source>
        <translation>Behøver genstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth blev lige installeret, det kan være nødvendigt at genstarte inden du kan vise forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>Click to select theme</source>
        <translation>Klik for at vælge tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Du skal køre programmet som root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Program for selecting common start-up choices</source>
        <translation type="unfinished">Program til at være almindelige opstartsvalg</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Select image to display in bootloader</source>
        <translation>Vælg billede som skal vises i opstartsindlæser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="941"/>
        <source>Select GRUB theme</source>
        <translation>Vælg GRUB-tema</translation>
    </message>
</context>
</TS>
